/*
 * Copyright (C) 2009 Sakari Poussa
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, version 2.
 */

#include <QtCore/QtCore>
#include <QtGui/QtGui>

#include "main-window.h"

int main(int argc, char *argv[])
{
  QApplication app(argc, argv);

  QCoreApplication::setOrganizationName("garage");
  QCoreApplication::setOrganizationDomain("maemo.org");
  QCoreApplication::setApplicationName("ScoreCard");

  MainWindow win;
  win.show();

  return app.exec();
}
